# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [3.0.0] - 2021-09-16

### Changed

- Bumped `mitol-django-common` requirement to `~=2.0.0`

## [2.2.0] - 2021-06-28

### Changed

- Support newer versions of `factory_boy`

## [2.1.0] - 2021-06-24

### Changed

- Allowed for a wider range of dependency versions

## [2.0.0] - 2021-06-23

### Added
- Support for Python 3.9

### Removed
- Support for Python 3.6

## [1.0.0] - 2021-03-31
### Changed
- Bumped `mitol-django-common` requirement to `^0.7.0`

## [0.5.0] - 2021-03-31

### Changed
- Bumped `mitol-django-common` requirement to `~0.6.0`

## [0.4.0] - 2021-03-26

### Added

- Added boilerplate configuration settings for email (`mitol.common.settings.email`)

## [0.3.0] - 2021-01-21

### Changed
- Updated `mitol-django-common` to `0.4.0`

## [0.2.0] - 2021-01-15

### Added
- Support Django 3.x

## [0.1.6] - 2020-10-14

### Fixed
- Removed `LICENSE` explicitly added in `pyproject.toml`
- Added `py.typed` marker file per [PEP 561](https://www.python.org/dev/peps/pep-0561/#packaging-type-information)

## [0.1.5] - 2020-09-30
### Added
- Add support for `anymail` versions 6.x, 7.x, 8.x
- Add support for `toolz` 0.10.x

## [0.1.4] - 2020-09-29
### Fixed
- Added `--build` flag to `poetry publish`

## [0.1.3] - 2020-09-29
### Fixed
- Removed erroneous `$` character in CI workflow

## [0.1.2] - 2020-09-29
### Fixed
- Fixed release workflow version extraction

## [0.1.1] - 2020-09-29
### Fixed
- Attempted fix of GitHub CI pipeline

## [0.1.0] - 2020-09-29
### Added
- Initial port of the `mail` app

[Unreleased]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v3.0.0...HEAD
[3.0.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v2.2.0...mitol-django-mail/v3.0.0
[2.2.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v2.1.0...mitol-django-mail/v2.2.0
[2.1.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v2.0.0...mitol-django-mail/v2.1.0
[2.0.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v1.0.0...mitol-django-mail/v2.0.0
[1.0.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v1.0.0
[0.5.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.5.0
[0.4.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.4.0
[0.3.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.3.0
[0.2.0]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.2.0
[0.1.6]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.1.6
[0.1.5]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.1.5
[0.1.4]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.1.4
[0.1.3]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.1.3
[0.1.2]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.1.2
[0.1.1]: https://github.com/mitodl/ol-django/compare/mitol-django-mail/v0.1.0...mitol-django-mail/v0.1.1
[0.1.0]: https://github.com/mitodl/ol-django/compare/ffca0142e4bfea14881047d3af168bd4aa32f6fa...mitol-django-mail/v0.1.0
